e3-testsuite
============

Generic testsuite framework in Python. Supports Python 3.9 and Python 3.10.
Full documentation available on [Read the
Docs](https://e3-testsuite.readthedocs.io/en/latest/).


Installation
------------

This package is available on [Pypi](https://pypi.org/project/e3-testsuite/). If
you want to install it from the source, run the following command in the root
directory:

```shell
pip install .
```


Testing
-------

Contributors are expected to run `tox` and keep the testsuite and style
checks clean. Please also add tests so that code coverage never degrades.

The testsuite is based on the [pytest](https://docs.pytest.org/en/latest/)
framework.
